#!/usr/bin/env python
# -*- coding: utf-8 -*-
# Inspire by Conbagui tutorial found here: https://www.deviantart.com/conbagui/art/Create-Nice-Mothers-Day-Card-with-Gimp-2-10-795783382
# author: Pocholo
# date: 1/28/2021

# Comments directed to http://gimpchat.com

# Installation:
# This script should be placed in the user plugin folder

# Copyright (C)

#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by   
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.

#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program.  If not, see <https://www.gnu.org/licenses/>.

from gimpfu import *
import gettext
gettext.install("gimp20-python", gimp.locale_directory, unicode=True)
def create_valentine_day_card_ver2(pattern, ribboncolor, heartcolor, lacecolor, customtext, fontname, textsize, fontcolor):
				
	#Initiates the temporary state
	pdb.gimp_context_set_defaults()
	pdb.gimp_context_set_default_colors()		
	
	#Variables	
	size = 2000
		
	#Create background layer
	img = pdb.gimp_image_new(size, size, RGB)
	backLayer = pdb.gimp_layer_new(img, size, size, RGB, "Background", 100, LAYER_MODE_NORMAL)
	pdb.gimp_layer_add_alpha(backLayer)
	pdb.gimp_image_add_layer(img, backLayer, 0)
	pdb.gimp_context_set_pattern(pattern)
	pdb.gimp_drawable_edit_fill(backLayer, FILL_PATTERN)
	pdb.gimp_display_new(img)
	
	#Create the ribbon
	ribbonLayer = pdb.gimp_layer_new(img, size, size, RGB_IMAGE, "Ribbon", 100, LAYER_MODE_NORMAL)	
	pdb.gimp_image_add_layer(img, ribbonLayer, 0)
	pdb.gimp_layer_add_alpha(ribbonLayer)
	pdb.gimp_drawable_fill(ribbonLayer, FILL_TRANSPARENT)
	pdb.gimp_context_set_foreground(ribboncolor)
	pdb.gimp_image_select_rectangle(img, 2, 0, 850, 2000, 300)
	pdb.gimp_edit_bucket_fill(ribbonLayer, BUCKET_FILL_FG, LAYER_MODE_NORMAL, 100, 255, FALSE, 0, 0)
	pdb.python_layerfx_outer_glow(img, ribbonLayer, 
								         (0, 0, 0),	 #color 
										  	   75,   #opacity
											     0,   #contou
											     0,   #noise
											     3,   #mode - multiply
											     0,   #spread 
											    6,   #size 
											  TRUE,   #knockout 
										     FALSE)   #merge	
	
	
	#Create the stitches on the ribbon
	stitches = pdb.gimp_layer_new(img, size, size, RGB, "Stitches", 100, LAYER_MODE_NORMAL)
	pdb.gimp_image_add_layer(img, stitches, 0)
	pdb.gimp_layer_add_alpha(stitches)
	pdb.gimp_drawable_fill(stitches, FILL_TRANSPARENT)
	pdb.gimp_selection_shrink(img, 35)
	pdb.plug_in_sel2path(img, stitches)
	pdb.gimp_selection_none(img)
	pdb.gimp_context_set_foreground('White')	
	pdb.gimp_brushes_set_brush("Solid Rectangle")
	pdb.gimp_context_set_brush_size(25)
	pdb.gimp_context_set_brush_angle(0)
	pdb.gimp_context_set_brush_spacing(1.5)
	pdb.gimp_context_set_brush_default_hardness()
	pdb.gimp_context_set_paint_method("gimp-paintbrush")
	pdb.gimp_context_set_stroke_method(STROKE_PAINT_METHOD)
	vectors1 = pdb.gimp_image_get_vectors_by_name(img,_("Selection"))
	pdb.gimp_drawable_edit_stroke_item(stitches, vectors1)
	pdb.gimp_layer_scale(stitches, 3000, 2000, TRUE)
	pdb.gimp_layer_resize_to_image_size(stitches)
	pdb.python_layerfx_outer_glow(img, stitches, 
								      (0, 0, 0),   #color 
										  	100,   #opacity
											  0,   #contou
											  0,   #noise
											  3,   #mode - multiply
											  0,   #spread 
											  3,   #size 
										   TRUE,   #knockout 
										  FALSE)   #merge	
	
	#Create a new from visible and rotate layer
	pdb.gimp_item_set_visible(backLayer, FALSE)
	ribbon2 = pdb.gimp_layer_new_from_visible(img, img, "Lace Text")
	pdb.gimp_image_add_layer(img, ribbon2, 0)
	ribbon2 = pdb.gimp_item_transform_rotate_simple(ribbon2, ROTATE_90, TRUE, 100, 100)
	pdb.gimp_item_set_visible(backLayer, TRUE)
	pdb.gimp_item_set_name(ribbon2, "Ribbon (vertical)")
	
	#Create the heart
	heartLayer = pdb.gimp_layer_new(img, size, size, RGB_IMAGE, "Heart", 100, LAYER_MODE_NORMAL)
	pdb.gimp_layer_add_alpha(heartLayer)
	pdb.gimp_image_add_layer(img, heartLayer, 0)
	pdb.gimp_drawable_fill(heartLayer, FILL_TRANSPARENT)
	pdb.gimp_brushes_set_brush("Best heart")
	pdb.gimp_context_set_brush_size(1500)
	pdb.gimp_context_set_brush_default_hardness()
	pdb.gimp_context_set_brush_spacing(0.01)
	pdb.gimp_context_set_brush_force(1)
	pdb.gimp_context_set_foreground(heartcolor)
	pdb.gimp_paintbrush_default(heartLayer, 2, [1000, 1000])
	pdb.gimp_paintbrush_default(heartLayer, 2, [1000, 1000])
	
	#Create the lacing on the heart
	laceLayer = pdb.gimp_layer_new(img, size, size, RGB, "Lace", 100, LAYER_MODE_NORMAL)
	pdb.gimp_image_add_layer(img, laceLayer, 1)
	pdb.gimp_layer_add_alpha(laceLayer)
	pdb.gimp_drawable_fill(laceLayer, FILL_TRANSPARENT)
	pdb.gimp_image_select_item(img, 2, heartLayer)
	pdb.plug_in_sel2path(img, laceLayer)
	pdb.gimp_selection_none(img)
	pdb.gimp_context_set_foreground(lacecolor)	
	pdb.gimp_brushes_set_brush("Lace heart brush")
	pdb.gimp_context_set_brush_size(250)
	pdb.gimp_context_set_brush_angle(0)
	pdb.gimp_context_set_brush_spacing(0.85)
	pdb.gimp_context_set_brush_default_hardness()
	pdb.gimp_context_set_paint_method("gimp-paintbrush")
	pdb.gimp_context_set_stroke_method(STROKE_PAINT_METHOD)
	vectors2 = pdb.gimp_image_get_vectors_by_name(img, (_("Selection")+' #1'))
	pdb.gimp_drawable_edit_stroke_item(laceLayer, vectors2)
	pdb.python_layerfx_outer_glow(img, laceLayer, 
								         (0, 0, 0),	 #color 
										  	    40,   #opacity
											     0,   #contou
											     0,   #noise
											     3,   #mode - multiply
											     0,   #spread 
											     5,   #size 
											  TRUE,   #knockout 
										     FALSE)   #merge	
											 
	
	#Create the lacing stitches
	stiches2 = pdb.gimp_layer_new(img, size, size, RGB, "Lacing stitches", 100, LAYER_MODE_NORMAL)
	pdb.gimp_image_add_layer(img, stiches2, 0)
	pdb.gimp_layer_add_alpha(stiches2)
	pdb.gimp_drawable_fill(stiches2, FILL_TRANSPARENT)	
	pdb.gimp_image_select_item(img, 2, heartLayer)
	pdb.gimp_selection_shrink(img, 35)
	pdb.plug_in_sel2path(img, stiches2)	
	pdb.gimp_selection_none(img)
	pdb.gimp_context_set_foreground('White')	
	pdb.gimp_context_set_line_cap_style(1)
	pdb.gimp_context_set_line_dash_offset(0)
	pdb.gimp_context_set_line_dash_pattern(3, [1.5, 3])
	pdb.gimp_context_set_line_join_style(JOIN_ROUND)
	pdb.gimp_context_set_line_miter_limit(10)
	pdb.gimp_context_set_line_width(10)
	pdb.gimp_context_set_line_width_unit(PIXELS)
	pdb.gimp_context_set_stroke_method (STROKE_LINE)
	vectors3 = pdb.gimp_image_get_vectors_by_name(img, _("Selection")+' #2')
	pdb.gimp_drawable_edit_stroke_item(stiches2, vectors3)
	pdb.python_layerfx_outer_glow(img, stiches2, 
								      (0, 0, 0),   #color 
										   	 75,   #opacity
											  0,   #contou
											  0,   #noise
											  3,   #mode - multiply
											  3,   #spread 
											  3,   #size 
										   TRUE,   #knockout 
										  FALSE)   #merge	
	
	#Create the text		
	textW = size/3.3
	textH = size/3.3
	pdb.gimp_context_set_foreground(fontcolor)
	textLayer = pdb.gimp_text_fontname(img, None, 0, 0, customtext, 10, 1, textsize, PIXELS, fontname)
	pdb.gimp_text_layer_set_justification(textLayer, TEXT_JUSTIFY_CENTER)
	pdb.gimp_text_layer_set_letter_spacing(textLayer, 0)
	pdb.gimp_text_layer_set_line_spacing(textLayer, -30)
	
	#Resize text
	pdb.gimp_layer_scale (textLayer, textW, textH, TRUE)
	
	#Making the text centered	
	textLayer = pdb.gimp_image_get_active_layer(img)
	pdb.gimp_image_set_active_layer(img, textLayer)
	wh = pdb.gimp_drawable_width(textLayer)
	hh = pdb.gimp_drawable_height(textLayer)
	w = pdb.gimp_image_width(img)
	h = pdb.gimp_image_height(img)
	pdb.gimp_image_set_active_layer(img,textLayer)
	centerx=w/2
	centery=h/2
	adw=wh/2
	adh=hh/2
	sw=centerx - adw
	sh=centery - adh		
	pdb.gimp_layer_set_offsets(textLayer, sw, sh)
	pdb.gimp_layer_resize_to_image_size(textLayer)
	pdb.gimp_layer_set_offsets(textLayer, 15, 40)
	pdb.gimp_layer_resize_to_image_size(textLayer)
	pdb.python_layerfx_outer_glow(img, textLayer, 
								      (0, 0, 0),   #color 
										   	 30,   #opacity
											  0,   #contou
											  0,   #noise
											  3,   #mode - multiply
											  0,   #spread 
											  3,   #size 
										   TRUE,   #knockout 
										  FALSE)   #merge	
	
	#Design
	designLayer = pdb.gimp_layer_new(img, size, size, RGB_IMAGE, "Designs", 100, LAYER_MODE_NORMAL)
	pdb.gimp_layer_add_alpha(designLayer)
	pdb.gimp_image_add_layer(img, designLayer, 0)
	pdb.gimp_drawable_fill(designLayer, FILL_TRANSPARENT)
	pdb.gimp_brushes_set_brush("Flowers & Swirls 1")
	pdb.gimp_context_set_brush_size(200)
	pdb.gimp_context_set_brush_default_hardness()
	pdb.gimp_context_set_brush_spacing(0.01)
	pdb.gimp_context_set_brush_force(0.50)
	pdb.gimp_context_set_foreground('White')
	pdb.gimp_paintbrush_default(designLayer, 2, [636, 772])
	non_empty = pdb.gimp_edit_copy(designLayer)
	designcopy = pdb.gimp_layer_new(img, size, size, RGB_IMAGE, "Designs copy", 100, LAYER_MODE_NORMAL)
	pdb.gimp_layer_add_alpha(designcopy)
	pdb.gimp_image_add_layer(img, designcopy, 0)
	pdb.gimp_drawable_fill(designcopy, FILL_TRANSPARENT)
	designcopy = pdb.gimp_edit_paste(designcopy, FALSE)
	pdb.gimp_floating_sel_anchor(designcopy)
	designcopy = pdb.gimp_image_get_layer_by_name(img, "Designs copy")
	designcopy = pdb.gimp_flip(designcopy, ORIENTATION_HORIZONTAL)
	designcopy = pdb.gimp_image_merge_down(img, designcopy, CLIP_TO_IMAGE)
	designLayer = pdb.gimp_image_get_layer_by_name(img, "Designs")
	pdb.python_layerfx_outer_glow(img, designLayer, 
								         (0, 0, 0),   #color 
										   	    15,   #opacity
											     0,   #contou
											     0,   #noise
											     3,   #mode - multiply
											     0,   #spread 
											     3,   #size 
										      TRUE,   #knockout 
										     FALSE)   #merge	
		
	#Set gimp to default
	pdb.gimp_context_set_defaults()
	pdb.gimp_context_set_default_colors()
	
register(
	"create_valentine_day_card_ver2",
	"Creates a Valentine day card",
	"Creates a Valentine day card",
	"Pocholo",
	"Pocholo",
	"2021",
	"Create a Valentine day card",
	"",
    [
	(PF_PATTERN, "pattern", "Background pattern", "Hearts pattern.jpg"),
	(PF_COLOR, "ribboncolor", "Ribbon color", (244, 178, 184)),
	(PF_COLOR, "heartcolor", "Heart color", (244, 178, 184)),
    (PF_COLOR, "lacecolor", "Lace color", (255, 255, 255)),	
    (PF_TEXT, "customtext", "Text string", "Happy\nValentine's\nDay"),
	(PF_FONT, "fontname", "Font name", "Fiolex Girls"),
	(PF_SPINNER, "textsize", "Text size", 185, (185, 185, 1)),
    (PF_COLOR, "fontcolor", "Font color", (255, 255, 255)),
        
    ],
    [],
    create_valentine_day_card_ver2, menu="<Image>/Pocholo-scripts/Create a Valentine day card",
    domain=("gimp20", gimp.locale_directory))
main()			